@@ -249,6 +249,9 @@ var HELP = {
     'queue-initial-cluster-size':
        'Set the queue initial cluster size.',
 
+    'quorum-queue-target-group-size':
+       'The target number of replicas. Used by the <a target="_blank" href="https://www.rabbitmq.com/docs/quorum-queues#member-reconciliation">periodic membership reconciliation</a> mechanism.<br/>',
+
     'queue-type':
        'Set the queue type, determining the type of queue to use: raft-based high availability or classic queue. Valid values are <code>quorum</code> or <code>classic</code>. It defaults to <code>classic</code>. <br/>',
 
@@ -707,7 +710,7 @@ function DisplayControl() {
   this.vhosts = false
   this.rabbitmqVersions = false
 
-  this.update = function(overview, ui_data_model) {    
+  this.update = function(overview, ui_data_model) {
     this.nodes = ac.canListNodes() && ui_data_model.nodes.length > 1
     this.vhosts = ac.canAccessVhosts()
     this.rabbitmqVersions = false
@@ -740,7 +743,7 @@ function setup_global_vars(overview) {
       '<li>Cluster ' + (user_administrator ?  '<a href="#/cluster-name">' + cluster_name + '</a>' : cluster_name) + '</li>'
     );
 
-    user_name = fmt_escape_html(user.name); 
+    user_name = fmt_escape_html(user.name);
     $('#header #logout').prepend(
       'User ' + (user_administrator && user.is_internal_user ?  '<a href="#/users/' + user_name + '">' + user_name + '</a>' : user_name)
     );
@@ -918,7 +921,7 @@ var QUEUE_TYPE = function (queue) {
 QUEUE_TYPE["default"] = {
     label: "Default",
     params: {},
-    policy_apply_to: "classic_queue",
+    policy_apply_to: "classic_queues",
     actions: {
         get_message: true,
         purge: true
@@ -938,7 +941,7 @@ QUEUE_TYPE["default"] = {
 QUEUE_TYPE["classic"] = {
     label: "Classic",
     params: {},
-    policy_apply_to: "classic_queue",
+    policy_apply_to: "classic_queues",
     actions: {
         get_message: true,
         purge: true
